@@ -215,92 +215,6 @@ var page_devices =
       ] ]
     ] ],
     [ "USRP2 and N2x0 Series", "page_usrp2.html", "page_usrp2" ],
-    [ "USRP N3xx Series", "page_usrp_n3xx.html", [
-      [ "Comparative features list", "page_usrp_n3xx.html#n3xx_feature_list", [
-        [ "N310/N300 4-channel/2-channel Transceiver", "page_usrp_n3xx.html#n3xx_feature_list_mg", null ],
-        [ "N320/N321 2-channel Transceiver", "page_usrp_n3xx.html#n3xx_feature_list_rh", null ]
-      ] ],
-      [ "Overview", "page_usrp_n3xx.html#n3xx_overview", [
-        [ "The Zynq CPU/FPGA and host operating system", "page_usrp_n3xx.html#n3xx_zynq", null ],
-        [ "The STM32 microcontroller", "page_usrp_n3xx.html#n3xx_micro", null ],
-        [ "The SD card", "page_usrp_n3xx.html#n3xx_sdcard", null ]
-      ] ],
-      [ "Getting started", "page_usrp_n3xx.html#n3xx_getting_started", [
-        [ "Assembling the N3XX", "page_usrp_n3xx.html#n3xx_getting_started_assembling", null ],
-        [ "Updating the file system", "page_usrp_n3xx.html#n3xx_getting_started_fs_update", [
-          [ "The External Method on Linux", "page_usrp_n3xx.html#n3xx_fs_update_linux", null ],
-          [ "The External Method on Windows", "page_usrp_n3xx.html#n3xx_fs_update_windows", null ]
-        ] ],
-        [ "Serial connection", "page_usrp_n3xx.html#n3xx_getting_started_serial", [
-          [ "Connecting to the microcontroller", "page_usrp_n3xx.html#n3xx_getting_started_serial_micro", null ]
-        ] ],
-        [ "SSH connection", "page_usrp_n3xx.html#n3xx_getting_started_ssh", null ],
-        [ "Network Connectivity", "page_usrp_n3xx.html#n3xx_getting_started_connectivity", null ],
-        [ "Security-related settings", "page_usrp_n3xx.html#n3xx_getting_started_security", null ],
-        [ "Updating the FPGA", "page_usrp_n3xx.html#n3xx_getting_started_fpga_update", [
-          [ "FPGA Image Flavors", "page_usrp_n3xx.html#n3xx_getting_started_fpga_update_flavors", null ]
-        ] ]
-      ] ],
-      [ "Using an N3XX USRP from UHD", "page_usrp_n3xx.html#n3xx_usage", [
-        [ "Device arguments", "page_usrp_n3xx.html#n3xx_usage_device_args", null ],
-        [ "Device Initialization", "page_usrp_n3xx.html#n3xx_usage_init", null ],
-        [ "Subdev Specifications", "page_usrp_n3xx.html#n3xx_usage_subdevspec", null ],
-        [ "The sensor API", "page_usrp_n3xx.html#n3xx_usage_sensors", null ]
-      ] ],
-      [ "Remote Management", "page_usrp_n3xx.html#n3xx_rasm", [
-        [ "Mender: Remote update capability", "page_usrp_n3xx.html#n3xx_rasm_mender", null ],
-        [ "Salt: Remote configuration management and execution", "page_usrp_n3xx.html#n3xx_rasm_salt", null ]
-      ] ],
-      [ "Clock/Time Synchronization", "page_usrp_n3xx.html#n3xx_synchronization", [
-        [ "Overview", "page_usrp_n3xx.html#n3xx_synchronization_overview", null ],
-        [ "Internal references", "page_usrp_n3xx.html#n3xx_synchronization_internal", null ],
-        [ "External references", "page_usrp_n3xx.html#n3xx_synchronization_external", null ],
-        [ "White Rabbit", "page_usrp_n3xx.html#n3xx_synchronization_whiterabbit", null ]
-      ] ],
-      [ "The Front-Panel GPIO", "page_usrp_n3xx.html#n3xx_fpgio", null ],
-      [ "Troubleshooting", "page_usrp_n3xx.html#n3xx_troubleshooting", [
-        [ "Errors while streaming", "page_usrp_n3xx.html#n3xx_troubleshooting_seqerrs", null ],
-        [ "Built-in Self-Test (BiST)", "page_usrp_n3xx.html#n3xx_troubleshooting_bist", null ]
-      ] ],
-      [ "Theory of Operation", "page_usrp_n3xx.html#n3xx_theory_of_ops", null ],
-      [ "Building custom filesystems and SD card images", "page_usrp_n3xx.html#n3xx_fsbuild", [
-        [ "Using Docker to build filesystems", "page_usrp_n3xx.html#n3xx_fsbuild_docker", null ]
-      ] ],
-      [ "Modifying and compiling UHD and MPM for the N3XX", "page_usrp_n3xx.html#n3xx_software_dev", [
-        [ "Compiling MPM natively", "page_usrp_n3xx.html#n3xx_software_dev_mpm_native", null ],
-        [ "Obtaining an SDK", "page_usrp_n3xx.html#n3xx_software_dev_sdk", null ],
-        [ "SDK Usage", "page_usrp_n3xx.html#n3xx_software_dev_sdkusage", [
-          [ "Building UHD", "page_usrp_n3xx.html#n3xx_software_dev_uhd", null ],
-          [ "Building GNU Radio", "page_usrp_n3xx.html#n3xx_software_dev_gr", null ]
-        ] ]
-      ] ],
-      [ "N310-specific Features", "page_usrp_n3xx.html#n3xx_mg", [
-        [ "Front and Rear Panel", "page_usrp_n3xx.html#n3xx_mg_panels", null ],
-        [ "Device Initialization (Fast and Slow)", "page_usrp_n3xx.html#n3xx_mg_initialization", null ],
-        [ "RF Calibrations", "page_usrp_n3xx.html#n3xx_mg_calibrations", null ],
-        [ "External LOs", "page_usrp_n3xx.html#n3xx_mg_external_lo", null ],
-        [ "Storing user data in the EEPROM", "page_usrp_n3xx.html#n3xx_mg_eeprom", null ],
-        [ "Module and Motherboard/Daughterboard Revisions", "page_usrp_n3xx.html#n3xx_mg_revs", null ],
-        [ "FPGA Register Map", "page_usrp_n3xx.html#n3xx_mg_regmap", null ],
-        [ "EEPROM flags", "page_usrp_n3xx.html#n3xx_mg_eeprom_flags", null ],
-        [ "Gain Profiles", "page_usrp_n3xx.html#n3xx_mg_gain_profiles", null ],
-        [ "Custom Band Edges", "page_usrp_n3xx.html#n3xx_mg_custom_band_edges", null ]
-      ] ],
-      [ "In this example, the second Rx band would start at 431 MHz.", "page_usrp_n3xx.html#autotoc_md57", [
-        [ "Filter API", "page_usrp_n3xx.html#n3xx_filter_api", null ]
-      ] ],
-      [ "N32x-specific Features", "page_usrp_n3xx.html#n3xx_rh", [
-        [ "Front and Rear Panel", "page_usrp_n3xx.html#n3xx_rh_panels", null ],
-        [ "Device Initialization (Fast and Slow)", "page_usrp_n3xx.html#n3xx_rh_initialization", null ],
-        [ "RF Calibrations", "page_usrp_n3xx.html#n3xx_rh_calibrations", null ],
-        [ "External LOs", "page_usrp_n3xx.html#n3xx_rh_external_lo", null ],
-        [ "N321 LO Distribution Board", "page_usrp_n3xx.html#n3xx_rh_lo_sharing", null ],
-        [ "N320/N321 LO Sharing", "page_usrp_n3xx.html#n3xx_rh_lo_chaining", null ],
-        [ "SFP+ and QSFP+ protocols", "page_usrp_n3xx.html#n3xx_rh_sfp_protocols", null ],
-        [ "N320/N321 Frontend Corrections", "page_usrp_n3xx.html#n3xx_rh_frontend_corrections", null ],
-        [ "EEPROM flags", "page_usrp_n3xx.html#n3xx_rh_eeprom_flags", null ]
-      ] ]
-    ] ],
     [ "USRP B2x0 Series", "page_usrp_b200.html", "page_usrp_b200" ],
     [ "USRP E3xx Series", "page_usrp_e3xx.html", [
       [ "Comparative features list", "page_usrp_e3xx.html#e3xx_feature_list", [
@@ -403,7 +317,6 @@ var page_devices =
       [ "E3XX FPGA Register Map", "page_usrp_e3xx.html#e3xx_regmap", null ]
     ] ],
     [ "USRP X3x0 Series", "page_usrp_x3x0.html", "page_usrp_x3x0" ],
-    [ "USRP X4x0 Series", "page_usrp_x4xx.html", "page_usrp_x4xx" ],
     [ "USRP1", "page_usrp1.html", [
       [ "Comparative features list", "page_usrp1.html#usrp1_features", null ],
       [ "Specify a Non-standard Image", "page_usrp1.html#usrp1_imgs", null ],
